from sdetools.sdelib.commons import UsageError
from sdetools.analysis_integration.base_integrator import BaseIntegrator, IntegrationError
from sdetools.modules.import_checkmarx.checkmarx_xml_importer import CheckmarxXMLImporter
from sdetools.modules.import_checkmarx.checkmarx_zip_importer import CheckmarxZIPImporter

__all__ = ['CheckmarxIntegrator']


class CheckmarxIntegrationError(IntegrationError):
    pass


class CheckmarxIntegrator(BaseIntegrator):
    TOOL_NAME = "checkmarx"
    DEFAULT_MAPPING_FILE = 'sde_checkmarx_map.csv'

    def __init__(self, config):
        supported_input_types = {
            'file': ['xml', 'zip']
        }
        super(CheckmarxIntegrator, self).__init__(config, self.TOOL_NAME, supported_input_types)

    def parse_report_file(self, report_file, report_type):
        if report_type == 'xml':
            importer = CheckmarxXMLImporter()
        elif report_type == 'zip':
            importer = CheckmarxZIPImporter()
        else:
            raise UsageError("Unsupported file type (%s)" % report_type)

        importer.parse(report_file)

        self.findings = importer.findings
        self.report_id = importer.id

        return importer.findings, importer.id

    def _make_finding(self, item):
        return {'weakness_id': item['id'], 'description': item['id'], 'type': 'check'}

    def generate_findings(self):
        return [self._make_finding(item) for item in self.findings]
